Structs
- Retriable
Request Builder - A
reqwest::RequestBuilderwrapper that automatically retries failed requests using an exponential back-off strategy powered by thebackoncrate. UseRequestBuilderExt::with_retryto construct one.
Traits
- Request
Builder Ext - Extension trait for
reqwest::RequestBuilderto add JSON and XML response handling
Functions
- handle_
json_ response - Handle an HTTP response by checking status and parsing JSON on success
- handle_
no_ response - Handle an HTTP response by checking status without parsing the body
- handle_
xml_ response - Handle an HTTP response by checking status and parsing XML on success