Module request_utils

Module request_utils 

Structs

RetriableRequestBuilder
A reqwest::RequestBuilder wrapper that automatically retries failed requests using an exponential back-off strategy powered by the backon crate. Use RequestBuilderExt::with_retry to construct one.

Traits

RequestBuilderExt
Extension trait for reqwest::RequestBuilder to add JSON and XML response handling

Functions

handle_json_response
Handle an HTTP response by checking status and parsing JSON on success
handle_no_response
Handle an HTTP response by checking status without parsing the body
handle_xml_response
Handle an HTTP response by checking status and parsing XML on success